require "studio_game/player"

module StudioGame
    describe Player do
    
    before do
        @initial_health = 150
        @player = Player.new("larry",@initial_health)
    end
    
    it "has a capitalize name" do
        
        expect(@player.name).to eq("Larry")
    end
    
    it "has an initial health" do
        expect(@player.health).to eq(150)
    end
    
    it "has a string representation" do
        expect(@player.to_s).to eq("I am Larry with health of 150 and a score of 150")
    end
    it "computes a score of the sum of the health and length of the name" do
        @player.found_treasure(Treasure.new(:hammer,50))
        @player.found_treasure(Treasure.new(:hammer,50))
        expect(@player.to_s).to eq("I am Larry with health of 150 and a score of 250")
    end
    it "increases health by 15 when woot" do
        @player.woot
        expect(@player.health).to eq(165)
    end
    it "decreaes health by 10 when blam" do
        @player.blam
        expect(@player.health).to eq(140)
    end
    
    it "computes points as the sum of all treasure points" do
        expect(@player.points).to eq(0) 
        
        @player.found_treasure(Treasure.new(:hammer,50))
        expect(@player.points).to eq(50)
        
        @player.found_treasure(Treasure.new(:crowbar,400))
        expect(@player.points).to eq(450)
        
        @player.found_treasure(Treasure.new(:hammer,50))
        expect(@player.points).to eq(500)
    end
    
    it "yields each treasure found and it's total points" do
        
        @player.found_treasure(Treasure.new(:hammer,50))
        @player.found_treasure(Treasure.new(:crowbar,400))
        @player.found_treasure(Treasure.new(:bow,100))
        @player.found_treasure(Treasure.new(:crowbar,400))
        @player.found_treasure(Treasure.new(:crowbar,400))
        @player.found_treasure(Treasure.new(:bow,100))
        
        yielded = []
        @player.each_treasure do |treasure|
            yielded << treasure
        end
        
       yielded.should == [
            Treasure.new(:hammer, 50),
            Treasure.new(:crowbar, 1200),
            Treasure.new(:bow, 200)
        ]      
        
    end
    
    
    context "Player has a health above 150" do
        
        before do
            @player = Player.new("moe",150)
        end
        
        it "player is strong when health is 150" do
            expect(@player).to be_strong
        end
        
    end
    
    context "Player has a health above 100" do
        
        before do
            @player = Player.new("moe",100)
        end
        
        it "player is not strong when health is below 100" do
            expect(@player).to_not be_strong
        end
        
    end
end    
end